@@ -3,24 +3,23 @@
 #endif
 
 #include <stdio.h>
+#include <stdbool.h>
 
 #include "error.h"
 #include "cdi.h"
 #include "basetime.h"
 
-#undef  UNDEFID
-#define UNDEFID  CDI_UNDEFID
 
 void basetimeInit(basetime_t *basetime)
 {
   if ( basetime == NULL )
     Error("Internal problem! Basetime not allocated.");
 
-  basetime->ncvarid       = UNDEFID;
-  basetime->ncdimid       = UNDEFID;
-  basetime->ncvarboundsid = UNDEFID;
-  basetime->leadtimeid    = UNDEFID;
-  basetime->lwrf          = 0;
+  basetime->ncvarid       = CDI_UNDEFID;
+  basetime->ncdimid       = CDI_UNDEFID;
+  basetime->ncvarboundsid = CDI_UNDEFID;
+  basetime->leadtimeid    = CDI_UNDEFID;
+  basetime->lwrf          = false;
   basetime->timevar_cache = NULL;
 }
 /*
@@ -32,4 +31,3 @@ void basetimeInit(basetime_t *basetime)
  * require-trailing-newline: t
  * End:
  */
- 
\ No newline at end of file
