@@ -17,14 +17,14 @@
 const char *cdfLibraryVersion(void)
 {
 #if  defined  (HAVE_LIBNETCDF)
-  return (nc_inq_libvers());
+  return nc_inq_libvers();
 #else
-  return ("library undefined");
+  return "library undefined";
 #endif
 }
 
-#if  defined(HAVE_LIBHDF5)
-#if defined(__cplusplus)
+#if  defined(HAVE_H5GET_LIBVERSION)
+#if  defined(__cplusplus)
 extern "C" {
 #endif
   int H5get_libversion(unsigned *, unsigned *, unsigned *);
@@ -35,17 +35,20 @@ extern "C" {
 
 const char *hdfLibraryVersion(void)
 {
-#if  defined(HAVE_LIBHDF5)
+#if  defined(HAVE_H5GET_LIBVERSION)
   static char hdf_libvers[256];
   unsigned majnum, minnum, relnum;
 
   H5get_libversion(&majnum, &minnum, &relnum);
 
-  sprintf(hdf_libvers, "%u.%u.%u", majnum, minnum, relnum);
-
-  return (hdf_libvers);
+#if  defined(HAVE_NC4HDF5_THREADSAFE)
+  sprintf(hdf_libvers, "%u.%u.%u threadsafe", majnum, minnum, relnum);
 #else
-  return ("library undefined");
+  sprintf(hdf_libvers, "%u.%u.%u", majnum, minnum, relnum);
+#endif
+  return hdf_libvers;
+#else
+  return "library undefined";
 #endif
 }
 
@@ -111,22 +114,22 @@ static int cdfOpenFile(const char *filename, const char *mode, int *filetype)
 	      (void) nc_inq_format(ncid, &format);
 	      if ( format == NC_FORMAT_NETCDF4_CLASSIC )
 		{
-		  *filetype = FILETYPE_NC4C;
+		  *filetype = CDI_FILETYPE_NC4C;
 		}
 	    }
 #endif
 	  break;
 	case 'w':
 #if  defined  (NC_64BIT_OFFSET)
-	  if      ( *filetype == FILETYPE_NC2  ) writemode |= NC_64BIT_OFFSET;
+	  if      ( *filetype == CDI_FILETYPE_NC2  ) writemode |= NC_64BIT_OFFSET;
 #endif
 #if  defined  (HAVE_NETCDF4)
-	  if      ( *filetype == FILETYPE_NC4  ) writemode |= NC_NETCDF4;
-	  else if ( *filetype == FILETYPE_NC4C ) writemode |= NC_NETCDF4 | NC_CLASSIC_MODEL;
+	  if      ( *filetype == CDI_FILETYPE_NC4  ) writemode |= NC_NETCDF4;
+	  else if ( *filetype == CDI_FILETYPE_NC4C ) writemode |= NC_NETCDF4 | NC_CLASSIC_MODEL;
 #endif
 	  cdf_create(filename, writemode, &ncid);
 	  if ( CDI_Version_Info ) cdfComment(ncid);
-          cdf_put_att_text(ncid, NC_GLOBAL, "Conventions", 6, "CF-1.4");
+          cdf_put_att_text(ncid, NC_GLOBAL, "Conventions", 6, "CF-1.6");
 	  break;
 	case 'a':
 	  cdf_open(filename, NC_WRITE, &ncid);
@@ -137,39 +140,38 @@ static int cdfOpenFile(const char *filename, const char *mode, int *filetype)
     }
 #endif
 
-  return (ncid);
+  return ncid;
 }
 
 
 int cdfOpen(const char *filename, const char *mode)
 {
-  int fileID = 0;
-  int filetype = FILETYPE_NC;
+  int filetype = CDI_FILETYPE_NC;
 
   if ( CDF_Debug )
     Message("Open %s with mode %c", filename, *mode);
 
-  fileID = cdfOpenFile(filename, mode, &filetype);
+  int fileID = cdfOpenFile(filename, mode, &filetype);
 
   if ( CDF_Debug )
     Message("File %s opened with id %d", filename, fileID);
 
-  return (fileID);
+  return fileID;
 }
 
 
 int cdfOpen64(const char *filename, const char *mode)
 {
   int fileID = -1;
-  int open_file = TRUE;
-  int filetype = FILETYPE_NC2;
+  int filetype = CDI_FILETYPE_NC2;
+  bool open_file = true;
 
   if ( CDF_Debug )
     Message("Open %s with mode %c", filename, *mode);
 
 #if  defined  (HAVE_LIBNETCDF)
 #if  ! defined  (NC_64BIT_OFFSET)
-  open_file = FALSE;
+  open_file = false;
 #endif
 #endif
 
@@ -185,20 +187,20 @@ int cdfOpen64(const char *filename, const char *mode)
       fileID = CDI_ELIBNAVAIL;
     }
 
-  return (fileID);
+  return fileID;
 }
 
 
 int cdf4Open(const char *filename, const char *mode, int *filetype)
 {
   int fileID = -1;
-  int open_file = FALSE;
+  bool open_file = false;
 
   if ( CDF_Debug )
     Message("Open %s with mode %c", filename, *mode);
 
 #if  defined  (HAVE_NETCDF4)
-  open_file = TRUE;
+  open_file = true;
 #endif
 
   if ( open_file )
@@ -213,7 +215,7 @@ int cdf4Open(const char *filename, const char *mode, int *filetype)
       fileID = CDI_ELIBNAVAIL;
     }
 
-  return (fileID);
+  return fileID;
 }
 
 
