@@ -37,10 +37,8 @@ int get_timeunit(size_t len, const char *ptu)
       else if ( str_is_equal(ptu, "calendar_month") ) timeunit = TUNIT_MONTH;
       else if ( str_is_equal(ptu, "year") )           timeunit = TUNIT_YEAR;
     }
-  else if ( len == 1 )
-    {
-      if ( ptu[0] == 's' ) timeunit = TUNIT_SECOND;
-    }
+  else if ( len == 1 && ptu[0] == 's' )
+    timeunit = TUNIT_SECOND;
 
   return timeunit;
 }
@@ -265,6 +263,8 @@ void set_gridtype(const char *attstring, int *gridtype)
     *gridtype = GRID_UNSTRUCTURED;
   else if ( strcmp(attstring, "curvilinear") == 0 )
     *gridtype = GRID_CURVILINEAR;
+  else if ( strcmp(attstring, "characterxy") == 0 )
+    *gridtype = GRID_CHARXY;
   else if ( strcmp(attstring, "sinusoidal") == 0 )
     ;
   else if ( strcmp(attstring, "laea") == 0 )
