@@ -30,9 +30,15 @@ struct gridVirtTable
   double (*inqXVal)(grid_t *gridptr, int index);
   double (*inqYVal)(grid_t *gridptr, int index);
   int (*inqXVals)(grid_t *gridptr, double *xvals);
+  int (*inqXCvals)(grid_t *gridptr, char **xcvals);
+  int (*inqXIsc)(grid_t *gridptr);
   int (*inqYVals)(grid_t *gridptr, double *yvals);
+  int (*inqYCvals)(grid_t *gridptr, char **ycvals);
+  int (*inqYIsc)(grid_t *gridptr);
   const double *(*inqXValsPtr)(grid_t *gridptr);
+  const char **(*inqXCvalsPtr)(grid_t *gridptr);
   const double *(*inqYValsPtr)(grid_t *gridptr);
+  const char **(*inqYCvalsPtr)(grid_t *gridptr);
   /* return if for both grids, all xval and all yval are equal */
   bool (*compareXYFull)(grid_t *gridRef, grid_t *gridTest);
   /* return if for both grids, x[0], y[0], x[size-1] and y[size-1] are
@@ -59,6 +65,8 @@ struct gridaxis_t {
   short   flag;                  // 0: undefined 1:vals 2:first+inc
   double  first, last, inc;
   double *vals;
+  int clength;
+  char  **cvals;
   double *bounds;
 };
 
@@ -126,6 +134,9 @@ void gridVerifyProj(int gridID);
 const double *gridInqXvalsPtr(int gridID);
 const double *gridInqYvalsPtr(int gridID);
 
+const char **gridInqXCvalsPtr(int gridID);
+const char **gridInqYCvalsPtr(int gridID);
+
 const double *gridInqXboundsPtr(int gridID);
 const double *gridInqYboundsPtr(int gridID);
 const double *gridInqAreaPtr(int gridID);
@@ -151,7 +162,7 @@ struct addIfNewRes
 
 struct addIfNewRes cdiVlistAddGridIfNew(int vlistID, grid_t *grid, int mode);
 
-int gridVerifyGribParamLCC(int gridID, double missval, double *lon_0, double *lat_0, double *lat_1, double *lat_2,
+int gridVerifyGribParamLCC(double missval, double *lon_0, double *lat_0, double *lat_1, double *lat_2,
                            double *a, double *rf, double *xval_0, double *yval_0, double *x_0, double *y_0);
 
 #endif
