@@ -1,3 +1,7 @@
+#if defined (HAVE_CONFIG_H)
+#  include "config.h"
+#endif
+
 #include "iterator_fallback.h"
 
 #include "cdi.h"
@@ -11,11 +15,12 @@
 
 struct CdiFallbackIterator {
   CdiIterator super;
-  int streamId, vlistId;
+  int streamId, vlistId, subtypeId;
   char *path;   //needed for clone() & serialize()
 
   int variableCount, curVariable;
   int curLevelCount, curLevel;
+  int curSubtypeCount, curSubtype;
   int curTimestep;
 };
 
@@ -39,12 +44,15 @@ static CdiFallbackIterator *cdiFallbackIterator_condestruct(CdiFallbackIterator
   if(me->vlistId == CDI_UNDEFID) goto closeStream;
   me->variableCount = vlistNvars(me->vlistId);
   if(me->variableCount <= 0) goto closeStream;
+  me->subtypeId = CDI_UNDEFID;   //Will be set in cdiFallbackIterator_nextField()
+  me->curSubtypeCount = -1;      //Will be set in cdiFallbackIterator_nextField()
   me->curLevelCount = -1;        //Will be set in cdiFallbackIterator_nextField()
 
   //These values are chosen so that the natural increment at the start of cdiFallbackIterator_nextField() will correctly position us at the first slice.
   me->curTimestep = 0;
   if(streamInqTimestep(me->streamId, me->curTimestep) <= 0) goto closeStream;
-  me->curVariable = 0;
+  me->curVariable = -1;
+  me->curSubtype = -1;
   me->curLevel = -1;
   me->path = strdup(path);
   if(!me->path) goto closeStream;
@@ -70,14 +78,20 @@ CdiIterator *cdiFallbackIterator_new(const char *path, int filetype)
   return &cdiFallbackIterator_condestruct(NULL, path, filetype)->super;
 }
 
-//Fetches the info that is published by the variables in the base class from the current field.
-static void fetchSuperInfo(CdiFallbackIterator *me)
+//Fetches the info that is derived from the current variable. Most of this is published by the data members in the base class.
+static void fetchVariableInfo(CdiFallbackIterator *me)
 {
+  //Fetch data that's published via base class data members.
   me->super.datatype = vlistInqVarDatatype(me->vlistId, me->curVariable);
   me->super.timesteptype = vlistInqVarTsteptype(me->vlistId, me->curVariable);
   me->super.gridId = vlistInqVarGrid(me->vlistId, me->curVariable);
   int param = vlistInqVarParam(me->vlistId, me->curVariable);
   cdiDecodeParam(param, &me->super.param.number, &me->super.param.category, &me->super.param.discipline);
+
+  //Fetch the current level and subtype counts.
+  me->curLevelCount = zaxisInqSize(vlistInqVarZaxis(me->vlistId, me->curVariable));
+  me->subtypeId = vlistInqVarSubtype(me->vlistId, me->curVariable);
+  me->curSubtypeCount = (me->subtypeId == CDI_UNDEFID) ? 1 : subtypeInqSize(me->subtypeId);
 }
 
 CdiFallbackIterator *cdiFallbackIterator_clone(CdiIterator *super)
@@ -93,10 +107,12 @@ CdiFallbackIterator *cdiFallbackIterator_clone(CdiIterator *super)
   clone->curVariable = me->curVariable;
   clone->curLevelCount = me->curLevelCount;
   clone->curLevel = me->curLevel;
+  clone->curSubtypeCount = me->curSubtypeCount;
+  clone->curSubtype = me->curSubtype;
   clone->curTimestep = me->curTimestep;
 
   clone->super.isAdvanced = super->isAdvanced;
-  if(super->isAdvanced) fetchSuperInfo(clone);
+  if(super->isAdvanced) fetchVariableInfo(clone);
 
   return clone;
 }
@@ -107,8 +123,8 @@ char *cdiFallbackIterator_serialize(CdiIterator *super)
 
   char *escapedPath = cdiEscapeSpaces(me->path);
   char *result = (char *) Malloc(strlen(escapedPath)
-                         + 5 * (3 * sizeof (int) * CHAR_BIT / 8 + 1) + 1);
-  sprintf(result, "%s %d %d %d %d %d", escapedPath, me->variableCount, me->curVariable, me->curLevelCount, me->curLevel, me->curTimestep);
+                         + 7 * (3 * sizeof (int) * CHAR_BIT / 8 + 1) + 1);
+  sprintf(result, "%s %d %d %d %d %d %d %d", escapedPath, me->variableCount, me->curVariable, me->curLevelCount, me->curLevel, me->curSubtypeCount, me->curSubtype, me->curTimestep);
   Free(escapedPath);
   return result;
 }
@@ -142,11 +158,13 @@ CdiFallbackIterator *cdiFallbackIterator_deserialize(const char *description)
   decodeValue(me->curVariable, description);
   decodeValue(me->curLevelCount, description);
   decodeValue(me->curLevel, description);
+  decodeValue(me->curSubtypeCount, description);
+  decodeValue(me->curSubtype, description);
   decodeValue(me->curTimestep, description);
 #undef decodeValue
 
   if(streamInqTimestep(me->streamId, me->curTimestep) <= 0) goto closeStream;
-  if(me->super.isAdvanced) fetchSuperInfo(me);
+  if(me->super.isAdvanced) fetchVariableInfo(me);
 
   return me;
 
@@ -164,15 +182,20 @@ fail:
 static int advance(CdiFallbackIterator *me)
 {
   me->curLevel++;
-  if(me->curLevel == me->curLevelCount)
+  if(me->curLevel >= me->curLevelCount)
     {
       me->curLevel = 0;
-      me->curVariable++;
-      if(me->curVariable == me->variableCount)
+      me->curSubtype++;
+      if(me->curSubtype >= me->curSubtypeCount)
         {
-          me->curVariable = 0;
-          me->curTimestep++;
-          if(streamInqTimestep(me->streamId, me->curTimestep) <= 0) return CDI_EEOF;
+          me->curSubtype = 0;
+          me->curVariable++;
+          if(me->curVariable >= me->variableCount)
+            {
+              me->curVariable = 0;
+              me->curTimestep++;
+              if(streamInqTimestep(me->streamId, me->curTimestep) <= 0) return CDI_EEOF;
+            }
         }
     }
   return CDI_NOERR;
@@ -184,21 +207,37 @@ int cdiFallbackIterator_nextField(CdiIterator *super)
   int result = advance(me);
   if(result) return result;
 
-  if(!me->curLevel)
-    { //Fetch the information that may have changed (we are processing a new variable/timestep if this point is reached).
-      fetchSuperInfo(me);
-      me->curLevelCount = zaxisInqSize(vlistInqVarZaxis(me->vlistId, me->curVariable));
-    }
+  if(!me->curLevel && !me->curSubtype) fetchVariableInfo(me);   //Check whether we are processing a new variable/timestep and fetch the information that may have changed in this case.
   return CDI_NOERR;
 }
 
-char *cdiFallbackIterator_inqTime(CdiIterator *super, bool getEndTime)
+char *cdiFallbackIterator_inqTime(CdiIterator *super, CdiTimeType timeType)
 {
   CdiFallbackIterator *me = (CdiFallbackIterator *)(void *)super;
-  if(getEndTime) return NULL;   //The stream interface does not export the start/end times of statistical fields, so we treat all data as point of time data, returning the validity time as the start time.
+
+  //retrieve the time information
   int taxisId = vlistInqTaxis(me->vlistId);
-  int date = taxisInqVdate(taxisId);
-  int time = taxisInqVtime(taxisId);
+  int date = 0, time = 0;
+  switch(timeType)
+    {
+      case kCdiTimeType_referenceTime:
+        date = taxisInqRdate(taxisId);
+        time = taxisInqRtime(taxisId);
+        break;
+
+      case kCdiTimeType_startTime:
+        date = taxisInqVdate(taxisId);
+        time = taxisInqVtime(taxisId);
+        break;
+
+      case kCdiTimeType_endTime:
+        return NULL;   //The stream interface does not export the start/end times of statistical fields, so we treat all data as point of time data, returning the validity time as the start time.
+
+      default:
+        assert(0 && "internal error, please report this bug");
+    }
+
+  //decode the time information and reencode it into an ISO-compliant string
   int year, month, day, hour, minute, second;
   cdiDecodeDate(date, &year, &month, &day);
   cdiDecodeTime(time, &hour, &minute, &second);
@@ -278,6 +317,58 @@ int cdiFallbackIterator_zaxisUuid(CdiIterator *super, int *outVgridNumber, int *
   return CDI_NOERR;
 }
 
+int cdiFallbackIterator_inqTile(CdiIterator *super, int *outTileIndex, int *outTileAttribute)
+{
+  CdiFallbackIterator *me = (CdiFallbackIterator*)(void *)super;
+#ifndef __cplusplus
+  if(!outTileIndex) outTileIndex = &(int){0};
+  if(!outTileAttribute) outTileAttribute = &(int){0};
+#else
+  int dummy = 0;
+  if(!outTileIndex) outTileIndex = &dummy;
+  if(!outTileAttribute) outTileAttribute = &dummy;
+#endif
+
+  int error = CDI_NOERR;
+  if(me->subtypeId == CDI_UNDEFID)	//must not call subtypeInqAttribute() with an invalid subtype ID, because it would abort the program instead of returning an error
+    {
+      error = CDI_EINVAL;
+    }
+  else
+    {
+      if(subtypeInqAttribute(me->subtypeId, me->curSubtype, "tileIndex", outTileIndex)) error = CDI_EINVAL;
+      if(subtypeInqAttribute(me->subtypeId, me->curSubtype, "tileAttribute", outTileAttribute)) error = CDI_EINVAL;
+    }
+  if(error) *outTileIndex = *outTileAttribute = -1; //Guarantee defined values in case of an error.
+  return error;
+}
+
+int cdiFallbackIterator_inqTileCount(CdiIterator *super, int *outTileCount, int *outTileAttributeCount)
+{
+  CdiFallbackIterator *me = (CdiFallbackIterator*)(void *)super;
+#ifndef __cplusplus
+  if(!outTileCount) outTileCount = &(int){0};
+  if(!outTileAttributeCount) outTileAttributeCount = &(int){0};
+#else
+  int temp = 0;
+  if(!outTileCount) outTileCount = &temp;
+  if(!outTileAttributeCount) outTileAttributeCount = &temp;
+#endif
+
+  int error = CDI_NOERR;
+  if(me->subtypeId == CDI_UNDEFID)	//must not call subtypeInqAttribute() with an invalid subtype ID, because it would abort the program instead of returning an error
+    {
+      error = CDI_EINVAL;
+    }
+  else
+    {
+      if(subtypeInqAttribute(me->subtypeId, me->curSubtype, "numberOfTiles", outTileCount)) error = CDI_EINVAL;
+      if(subtypeInqAttribute(me->subtypeId, me->curSubtype, "numberOfTileAttributes", outTileAttributeCount)) error = CDI_EINVAL;
+    }
+  if(error) *outTileCount = *outTileAttributeCount = -1; //Guarantee defined values in case of an error.
+  return CDI_NOERR;
+}
+
 char *cdiFallbackIterator_copyVariableName(CdiIterator *super)
 {
   CdiFallbackIterator *me = (CdiFallbackIterator*)(void *)super;
