@@ -13,12 +13,12 @@
 #include "resource_unpack.h"
 #include "serialize.h"
 
-#undef  UNDEFID
-#define UNDEFID -1
+#undef  CDI_UNDEFID
+#define CDI_UNDEFID -1
 
-static int ECHAM4 = UNDEFID,
-  ECHAM5 = UNDEFID,
-  COSMO  = UNDEFID;
+static int ECHAM4 = CDI_UNDEFID,
+  ECHAM5 = CDI_UNDEFID,
+  COSMO  = CDI_UNDEFID;
 
 typedef struct
 {
@@ -56,10 +56,10 @@ static const resOps modelOps = {
 static
 void modelDefaultValue ( model_t *modelptr )
 {
-  modelptr->self        = UNDEFID;
+  modelptr->self        = CDI_UNDEFID;
   modelptr->used        = 0;
-  modelptr->instID      = UNDEFID;
-  modelptr->modelgribID = UNDEFID;
+  modelptr->instID      = CDI_UNDEFID;
+  modelptr->modelgribID = CDI_UNDEFID;
   modelptr->name        = NULL;
 }
 
@@ -186,7 +186,7 @@ int modelInq(int instID, int modelgribID, const char *name)
 
   struct modelLoc searchState = { .name = name, .instID = instID,
                                   .modelgribID = modelgribID,
-                                  .resID = UNDEFID };
+                                  .resID = CDI_UNDEFID };
   if (name && *name)
     cdiResHFilterApply(&modelOps, findModelByName, &searchState);
   else
@@ -213,10 +213,10 @@ int modelInqInstitut(int modelID)
 
   modelInit ();
 
-  if ( modelID != UNDEFID )
+  if ( modelID != CDI_UNDEFID )
     modelptr = ( model_t * ) reshGetVal ( modelID, &modelOps );
 
-  return modelptr ? modelptr->instID : UNDEFID;
+  return modelptr ? modelptr->instID : CDI_UNDEFID;
 }
 
 
@@ -226,10 +226,10 @@ int modelInqGribID(int modelID)
 
   modelInit ();
 
-  if ( modelID != UNDEFID )
+  if ( modelID != CDI_UNDEFID )
     modelptr = ( model_t * ) reshGetVal ( modelID, &modelOps );
 
-  return modelptr ? modelptr->modelgribID : UNDEFID;
+  return modelptr ? modelptr->modelgribID : CDI_UNDEFID;
 }
 
 
@@ -239,7 +239,7 @@ const char *modelInqNamePtr(int modelID)
 
   modelInit ();
 
-  if ( modelID != UNDEFID )
+  if ( modelID != CDI_UNDEFID )
     modelptr = ( model_t * ) reshGetVal ( modelID, &modelOps );
 
   return modelptr ? modelptr->name : NULL;
@@ -298,8 +298,8 @@ enum {
 static int modelGetSizeP(void * modelptr, void *context)
 {
   model_t *p = (model_t*)modelptr;
-  size_t txsize = (size_t)serializeGetSize(model_nints, DATATYPE_INT, context)
-    + (size_t)serializeGetSize(p->name?(int)strlen(p->name) + 1:0, DATATYPE_TXT, context);
+  size_t txsize = (size_t)serializeGetSize(model_nints, CDI_DATATYPE_INT, context)
+    + (size_t)serializeGetSize(p->name?(int)strlen(p->name) + 1:0, CDI_DATATYPE_TXT, context);
   xassert(txsize <= INT_MAX);
   return (int)txsize;
 }
@@ -313,9 +313,9 @@ static void modelPackP(void * modelptr, void * buf, int size, int *position, voi
   tempbuf[1] = p->instID;
   tempbuf[2] = p->modelgribID;
   tempbuf[3] = p->name ? (int)strlen(p->name) + 1 : 0;
-  serializePack(tempbuf, model_nints, DATATYPE_INT, buf, size, position, context);
+  serializePack(tempbuf, model_nints, CDI_DATATYPE_INT, buf, size, position, context);
   if (p->name)
-    serializePack(p->name, tempbuf[3], DATATYPE_TXT, buf, size, position, context);
+    serializePack(p->name, tempbuf[3], CDI_DATATYPE_TXT, buf, size, position, context);
 }
 
 int
@@ -324,12 +324,12 @@ modelUnpack(void *buf, int size, int *position, int originNamespace, void *conte
 {
   int tempbuf[model_nints];
   char *name;
-  serializeUnpack(buf, size, position, tempbuf, model_nints, DATATYPE_INT, context);
+  serializeUnpack(buf, size, position, tempbuf, model_nints, CDI_DATATYPE_INT, context);
   if (tempbuf[3] != 0)
     {
       name = (char *) Malloc((size_t)tempbuf[3]);
       serializeUnpack(buf, size, position,
-                      name, tempbuf[3], DATATYPE_TXT, context);
+                      name, tempbuf[3], CDI_DATATYPE_TXT, context);
     }
   else
     {
