@@ -83,7 +83,6 @@ struct recordWrite
 };
 
 struct streamMapping {
-  int numVars;
   /* data entry varMap[i] contains data for variable i or -1 if no
    * data entry for i has been transferred */
   int *varMap;
@@ -93,6 +92,7 @@ struct streamMapping {
   /* nMiss[i] = missing values were provided for variable i */
   int *hasMissing;
   int numWrittenRecords;
+  int numVars;
   struct streamMemLayout *layout;
   struct recordWrite writtenRecords[];
 };
@@ -203,6 +203,8 @@ resizeVarGatherBuf(int size, double **buf, int *bufSize)
     *buf = Realloc(*buf, (size_t)(*bufSize = size) * sizeof (buf[0][0]));
 }
 
+#define wHECast struct winHeaderEntry *)(void *
+
 static Xt_redist
 buildVarRedist(int headerIdx, size_t streamIdx,
                /* index list representing the data elements gathered on
@@ -212,7 +214,7 @@ buildVarRedist(int headerIdx, size_t streamIdx,
 {
   const struct clientBuf *restrict clientBuf = rxWin[streamIdx].clientBuf;
   const struct winHeaderEntry *winDict
-    = (struct winHeaderEntry *)clientBuf[0].mem;
+    = (wHECast)clientBuf[0].mem;
   int streamID = openStreams.entries[streamIdx];
   int varID = winDict[headerIdx].specific.dataRecord.varID;
   struct Xt_offset_ext *partExts
@@ -224,14 +226,11 @@ buildVarRedist(int headerIdx, size_t streamIdx,
     {
       unsigned char *clientMem = clientBuf[clientIdx].mem;
       struct dataRecord *dataHeader
-        = &((struct winHeaderEntry *)clientMem)[headerIdx].specific.dataRecord;
-      int position = ((struct winHeaderEntry *)clientMem)[headerIdx + 1].offset;
-      xassert(namespaceAdaptKey2(((struct winHeaderEntry *)
-                                  clientMem)[headerIdx].id)
-              == streamID
+        = &((wHECast)clientMem)[headerIdx].specific.dataRecord;
+      int position = ((wHECast)clientMem)[headerIdx + 1].offset;
+      xassert(namespaceAdaptKey2(((wHECast)clientMem)[headerIdx].id) == streamID
               && dataHeader->varID == varID
-              && (((struct winHeaderEntry *)clientMem)[headerIdx + 1].id
-                  == PARTDESCMARKER)
+              && (((wHECast)clientMem)[headerIdx + 1].id == PARTDESCMARKER)
               && position > 0
               && ((size_t)position
                   >= sizeof (struct winHeaderEntry)
@@ -243,8 +242,7 @@ buildVarRedist(int headerIdx, size_t streamIdx,
       unsigned partSize
         = (unsigned)xt_idxlist_get_num_indices(part[clientIdx]);
       size_t charOfs = (size_t)((clientMem
-                                 + ((struct winHeaderEntry *)
-                                    clientMem)[headerIdx].offset)
+                                 + ((wHECast)clientMem)[headerIdx].offset)
                                 - clientBuf[0].mem);
       xassert(charOfs % sizeof (double) == 0
               && charOfs / sizeof (double) + partSize <= INT_MAX);
@@ -278,32 +276,11 @@ buildVarRedist(int headerIdx, size_t streamIdx,
 }
 
 
-static void
-gatherArray(int headerIdx, size_t streamIdx,
-            double *gatherBuf,
-            /* index list representing the data elements gathered on
-             * this rank */
-            Xt_idxlist dstList,
-            const struct cdiPioConf *conf)
-{
-  Xt_redist gatherRedist = buildVarRedist(headerIdx, streamIdx,
-                                          dstList, conf);
-  xt_redist_s_exchange1(gatherRedist,
-                        rxWin[streamIdx].clientBuf[0].mem, gatherBuf);
-  xt_redist_delete(gatherRedist);
-}
-
 struct xyzDims
 {
   int sizes[3];
 };
 
-static inline int
-xyzGridSize(struct xyzDims dims)
-{
-  return dims.sizes[0] * dims.sizes[1] * dims.sizes[2];
-}
-
 static Xt_idxlist
 buildVarSlicesIdxList(int vlistID, int varID, int startLvl, int numLvl)
 {
@@ -336,6 +313,23 @@ countVarChunkMissingVals(int vlistID, int varID,
   return nmiss;
 }
 
+#ifdef HAVE_LIBNETCDF
+static void
+gatherArray(int headerIdx, size_t streamIdx,
+            double *gatherBuf,
+            /* index list representing the data elements gathered on
+             * this rank */
+            Xt_idxlist dstList,
+            const struct cdiPioConf *conf)
+{
+  Xt_redist gatherRedist = buildVarRedist(headerIdx, streamIdx,
+                                          dstList, conf);
+  xt_redist_s_exchange1(gatherRedist,
+                        rxWin[streamIdx].clientBuf[0].mem, gatherBuf);
+  xt_redist_delete(gatherRedist);
+}
+#endif
+
 #ifdef HAVE_PARALLEL_NC4
 static void
 queryVarBounds(struct PPM_extent varShape[3], int vlistID, int varID)
@@ -572,7 +566,7 @@ writeNetCDFStream(size_t streamIdx,
 static inline struct winHeaderEntry *
 winDictEntry(size_t streamIdx, size_t client, size_t entry)
 {
-  return ((struct winHeaderEntry *)rxWin[streamIdx].clientBuf[client].mem)
+  return ((wHECast)rxWin[streamIdx].clientBuf[client].mem)
     + entry;
 }
 
@@ -596,7 +590,7 @@ getLayout(size_t streamIdx)
           = winDictEntry(streamIdx, client, headerIdx);
         size_t varID = (size_t)varHeader[0].specific.dataRecord.varID;
         size_t offset = (size_t)varHeader[0].offset;
-        Xt_uid uid = varHeader[1].specific.partDesc.uid;
+        Xt_uid uid = unpackXTUID(varHeader[1].specific.partDesc.packedUID);
         layout[client][varID] = (struct streamMemLayout){
           .varPartIdxListUID = uid, .offset = offset };
       }
@@ -750,14 +744,10 @@ struct passPlan
   int varStart, varEnd;
 };
 
-void
-deco1D_CCP(size_t n, const size_t weightPfxSums[n],
-           size_t nparts, size_t separators[nparts + 1]);
-
 /**
- * @param[out] passes pointer to pointer to 2-dimensional array of
+ * @param[out] passes_ pointer to pointer to 2-dimensional array of
  * records of dimensions $number of passes \cdot number of collectors$,
- * where $(*passes)[pass][i]$ details the records written by collector
+ * where $(*passes_)[pass][i]$ details the records written by collector
  * rank \a i
  * @return number of passes
  */
@@ -799,8 +789,8 @@ planPasses(size_t streamIdx, const struct streamMapping *mapping,
        * instead */
       numPasses = 1;
       struct passPlan *passes = Malloc(sizeof (*passes) * collSize);
-      deco1D_CCP(numWrittenRecords, recordDataSizePfxSums,
-                 collSize, recordSeparations);
+      cdiPioDeco1D_CCP(numWrittenRecords, recordDataSizePfxSums,
+                       collSize, recordSeparations);
       for (size_t rank = 0; rank < collSize; ++rank)
         {
           size_t startRecord = recordSeparations[rank],
@@ -854,18 +844,6 @@ planPasses(size_t streamIdx, const struct streamMapping *mapping,
   return numPasses;
 }
 
-static inline unsigned
-umax(unsigned a, unsigned b)
-{
-  return a >= b ? a : b;
-}
-
-static inline unsigned
-umin(unsigned a, unsigned b)
-{
-  return a <= b ? a : b;
-}
-
 static inline size_t
 szmin(size_t a, size_t b)
 {
@@ -1052,7 +1030,7 @@ writeGribStream(size_t streamIdx,
                                     * (size_t)1024 * (size_t)1024,
                                     sizeof (double) * myAggSize);
           if (posix_memalign(&rxWin[streamIdx].aggBuf,
-                             cdiPioGetPageSize(conf->largePageAlign),
+                             cdiGetPageSize(conf->largePageAlign),
                              aggBufSize) == 0) ;
           else
             rxWin[streamIdx].aggBuf = Malloc(aggBufSize);
@@ -1063,7 +1041,7 @@ writeGribStream(size_t streamIdx,
       {
         size_t varIdx = (size_t)-1;
         int varID = -1;
-        size_t base = 0;
+        size_t recordDataOfs = 0;
         const double *data = *data_;
         for (size_t recordIdx = myRecordStart;
              recordIdx <= myRecordEnd;
@@ -1077,9 +1055,9 @@ writeGribStream(size_t streamIdx,
             size_t nvals = recordSize / sizeof (double);
             int nmiss
               = countVarChunkMissingVals(vlistID, varID, mapping, (int)nvals,
-                                         data + base);
-            streamWriteVarSlice(streamID, varID, level, data + base, nmiss);
-            base += nvals;
+                                         data + recordDataOfs);
+            streamWriteVarSlice(streamID, varID, level, data + recordDataOfs, nmiss);
+            recordDataOfs += nvals;
           }
         aggBufFlush(streamIdx, cdiPioFileWrite);
       }
@@ -1102,7 +1080,7 @@ readGetBuffers(size_t streamIdx, const struct cdiPioConf *conf)
   xdebug("%s", "START");
 
   struct winHeaderEntry *winDict
-    = (struct winHeaderEntry *)rxWin[streamIdx].clientBuf[0].mem;
+    = (wHECast)rxWin[streamIdx].clientBuf[0].mem;
   xassert(winDict[0].id == HEADERSIZEMARKER);
   {
     int dictSize = rxWin[streamIdx].clientBuf[0].dictSize,
@@ -1131,14 +1109,14 @@ readGetBuffers(size_t streamIdx, const struct cdiPioConf *conf)
 
     switch (filetype)
       {
-      case FILETYPE_GRB:
-      case FILETYPE_GRB2:
+      case CDI_FILETYPE_GRB:
+      case CDI_FILETYPE_GRB2:
         writeGribStream(streamIdx, map, &data, &currentDataBufSize, conf);
         break;
 #ifdef HAVE_NETCDF4
-      case FILETYPE_NC:
-      case FILETYPE_NC2:
-      case FILETYPE_NC4:
+      case CDI_FILETYPE_NC:
+      case CDI_FILETYPE_NC2:
+      case CDI_FILETYPE_NC4:
         writeNetCDFStream(streamIdx, map, &data, &currentDataBufSize, conf);
         break;
 #endif
@@ -1207,7 +1185,7 @@ cdiPioServerStreamOpen(const char *filename, char filemode,
                        int filetype, stream_t *streamptr,
                        int recordBufIsToBeCreated)
 {
-  int fileID;
+  int fileID = -1;
 #if defined HAVE_LIBNETCDF && ! defined HAVE_PARALLEL_NC4
   /* Only needs initialization to shut up gcc */
   int rank = -1;
@@ -1215,8 +1193,8 @@ cdiPioServerStreamOpen(const char *filename, char filemode,
   switch (filetype)
     {
 #if defined HAVE_LIBNETCDF && ! defined HAVE_PARALLEL_NC4
-    case FILETYPE_NC4:
-    case FILETYPE_NC4C:
+    case CDI_FILETYPE_NC4:
+    case CDI_FILETYPE_NC4C:
       {
         int ioMode = commInqIOMode();
         if (ioMode == PIO_NONE
@@ -1280,10 +1258,10 @@ cdiPioServerStreamClose(stream_t *streamptr, int recordBufIsToBeDeleted)
       switch (filetype)
         {
 #if defined (HAVE_LIBNETCDF) && ! defined (HAVE_PARALLEL_NC4)
-        case FILETYPE_NC:
-        case FILETYPE_NC2:
-        case FILETYPE_NC4:
-        case FILETYPE_NC4C:
+        case CDI_FILETYPE_NC:
+        case CDI_FILETYPE_NC2:
+        case CDI_FILETYPE_NC4:
+        case CDI_FILETYPE_NC4C:
           {
             int rank, rankOpen = cdiPioSerialOpenFileMap(streamptr->self);
             if (commInqIOMode() == PIO_NONE
