@@ -30,11 +30,11 @@ typedef int MPI_Comm;
 
 static const struct model_config default_setup
 #ifdef __cplusplus
-= { 12, 6, 3, 5, 5, FILETYPE_GRB, DATATYPE_PACK24,1,"grb"};
+= { 12, 6, 3, 5, 5, CDI_FILETYPE_GRB, CDI_DATATYPE_PACK24,1,"grb"};
 #else
   = { .nlon = 12, .nts = 3, .nlat = 6, .nvars = 5,
-      .filetype = FILETYPE_GRB, .datatype = DATATYPE_PACK24,
-      .compute_checksum = 1,
+      .filetype = CDI_FILETYPE_GRB, .datatype = CDI_DATATYPE_PACK24,
+      .compute_checksum = 1, .create_uuid = 0,
       .suffix = "grb",
       .max_nlev = 5,
 };
@@ -44,13 +44,13 @@ static const struct {
   char suffix[4];
   int type, defaultDT, defaultGrid;
 } suffix2type[] = {
-  { "nc", FILETYPE_NC, DATATYPE_FLT64, GRID_LONLAT },
-  { "grb",  FILETYPE_GRB, DATATYPE_PACK24, GRID_LONLAT },
-  { "nc2", FILETYPE_NC2, DATATYPE_FLT64, GRID_LONLAT },
-  { "nc4", FILETYPE_NC4, DATATYPE_FLT64, GRID_LONLAT },
-  { "ext", FILETYPE_EXT, DATATYPE_FLT64, GRID_GENERIC, },
-  { "svc", FILETYPE_SRV, DATATYPE_FLT64, GRID_GENERIC, },
-  { "ieg", FILETYPE_IEG, DATATYPE_FLT64, GRID_LONLAT },
+  { "nc", CDI_FILETYPE_NC, CDI_DATATYPE_FLT64, GRID_LONLAT },
+  { "grb",  CDI_FILETYPE_GRB, CDI_DATATYPE_PACK24, GRID_LONLAT },
+  { "nc2", CDI_FILETYPE_NC2, CDI_DATATYPE_FLT64, GRID_LONLAT },
+  { "nc4", CDI_FILETYPE_NC4, CDI_DATATYPE_FLT64, GRID_LONLAT },
+  { "ext", CDI_FILETYPE_EXT, CDI_DATATYPE_FLT64, GRID_GENERIC, },
+  { "svc", CDI_FILETYPE_SRV, CDI_DATATYPE_FLT64, GRID_GENERIC, },
+  { "ieg", CDI_FILETYPE_IEG, CDI_DATATYPE_FLT64, GRID_LONLAT },
 };
 
 static void
@@ -96,11 +96,17 @@ parse_unsignedarg(const char msg[])
 typedef int (*pioRoleFunc)(MPI_Comm commSuper, int IOMode, int nProcsIO);
 
 static void
-parse_long_option(int pioConfHandle, pioRoleFunc *pioRoleAssign,
+parse_long_option(struct model_config *restrict setup,
+                  int pioConfHandle, pioRoleFunc *pioRoleAssign,
                   const char *str)
 {
+#ifndef USE_MPI
+  (void)pioConfHandle;
+  (void)pioRoleAssign;
+#endif
   static const char cacheRedistStr[] = "cache-redists",
-    pioRoleSchemeOptionStr[] = "pio-role-scheme";
+    pioRoleSchemeOptionStr[] = "pio-role-scheme",
+    uuidCreateOptionStr[] = "no-create-uuid";
   if (!strncmp(str, cacheRedistStr, sizeof (cacheRedistStr) - 1))
     {
 #ifdef USE_MPI
@@ -144,6 +150,14 @@ parse_long_option(int pioConfHandle, pioRoleFunc *pioRoleAssign,
                        pioRoleSchemeOptionStr);
 #endif
     }
+  else if (!strcmp(str, uuidCreateOptionStr + 3))
+    {
+      setup->create_uuid = true;
+    }
+  else if (!strcmp(str, uuidCreateOptionStr))
+    {
+      setup->create_uuid = false;
+    }
   else
     invalidOptionDie("unknown long option: %s\n", str);
 }
@@ -222,7 +236,7 @@ int main(int argc, char *argv[])
         break;
 #endif
       case 'q':
-        parse_long_option(pioConfHandle, &pioRoleAssign, optarg);
+        parse_long_option(&setup, pioConfHandle, &pioRoleAssign, optarg);
         break;
       case 'f':
         {
