@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2017 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -32,7 +32,10 @@
 #include <ctype.h>
 #include <stdarg.h>
 
+#include "pmlist.h"
+#include "listbuf.h"
 #include "compare.h"
+#include "array.h"
 #include "timebase.h"
 #include "field.h"
 #include "functs.h"
@@ -118,15 +121,8 @@ int     readline(FILE *fp, char *line, int len);
 
 int zaxis2ltype(int zaxisID);
 
+double radius_str_to_deg(const char *string);
 
-int nfc2nlat(int nfc, int ntr);
-int nlat2ntr(int nlat);
-int nlat2ntr_linear(int nlat);
-int ntr2nlat(int ntr);
-int ntr2nlat_linear(int ntr);
-int compNlon(int nlat);
-
-void param2str(int param, char *paramstr, int maxlen);
 void datetime2str(int date, int time, char *datetimestr, int maxlen);
 void date2str(int date, char *datestr, int maxlen);
 void time2str(int time, char *timestr, int maxlen);
@@ -134,7 +130,7 @@ void time2str(int time, char *timestr, int maxlen);
 const char * tunit2str(int tunits);
 const char * calendar2str(int calendar);
 
-void    defineGrid(const char *gridarg);
+void    cdo_set_grids(const char *gridarg);
 void    defineInstitution(const char *instarg);
 int     defineTable(const char *tablearg);
 
@@ -157,12 +153,29 @@ off_t fileSize(const char *restrict filename);
 
 char *expand_filename(const char *string);
 
+const char *parameter2word(const char *string);
 double parameter2double(const char *string);
+bool   parameter2bool(const char *string);
 int    parameter2int(const char *string);
 int    parameter2intlist(const char *string);
 
 int referenceToGrid(int gridID1);
 
+void cdo_read_field(const char *name, char *pline, int size, double *field, int *lineno, FILE *fp, const char *dname);
+
+double cdoZaxisInqLevel(int zaxisID, int levelID);
+int cdoZaxisInqLevels(int zaxisID, double *levels);
+
+list_t *namelistbuf_to_pmlist(listbuf_t *listbuf);
+list_t *namelist_to_pmlist(FILE *fp, const char *name);
+list_t *cmortable_to_pmlist(FILE *fp, const char *name);
+
+int literals_find_datatype(int n, char **literals);
+int literal_get_datatype(const char *literal);
+int literal_to_int(const char *literal);
+double literal_to_double(const char *literal);
+
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -177,6 +190,10 @@ void gaussaw(double *restrict pa, double *restrict pw, size_t nlat);
 int qu2reg3_double(double *pfield, int *kpoint, int klat, int klon,
 		   double msval, int *kret, int omisng, int operio, int oveggy);
 
+void cdoCompareGrids(int gridID1, int gridID2);
+void vlistCompare(int vlistID1, int vlistID2, int flag);
+int  vlistCompareX(int vlistID1, int vlistID2, int flag);
+
 #if defined (__cplusplus)
 }
 #endif
