@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2017 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 #ifndef _EXPR_FUN_H
 #define _EXPR_FUN_H
 
-void fld_field_init(field_t *field, size_t nmiss, double missval, size_t ngp, double *array, double *w);
+void fld_field_init(field_type *field, size_t nmiss, double missval, size_t ngp, double *array, double *w);
 double *fld_weights(int gridID, size_t ngp);
 double *vert_weights(int zaxisID, size_t nlev);
 
