@@ -11,15 +11,19 @@
 #define  func_sum      13
 #define  func_avg      14
 #define  func_mean     15
-#define  func_std      17
-#define  func_std1     18
-#define  func_var      19
-#define  func_var1     20
-
-#define  func_pctl     21
-
-#define  func_cor      22
-#define  func_covar    23
+#define  func_std      16
+#define  func_std1     17
+#define  func_var      18
+#define  func_var1     19
+#define  func_pctl     20
+#define  func_cor      21
+#define  func_covar    22
+#define  func_avgw     23
+#define  func_meanw    24
+#define  func_stdw     25
+#define  func_std1w    26
+#define  func_varw     27
+#define  func_var1w    28
 
 #define  func_crps     30
 #define  func_brs      31
@@ -57,7 +61,4 @@ enum cmp_flag {
   CMP_ALL      = CMP_NAME | CMP_GRIDSIZE | CMP_NLEVEL | CMP_GRID
 };
 
-void    vlistCompare(int vlistID1, int vlistID2, int flag);
-int     vlistCompareX(int vlistID1, int vlistID2, int flag);
-
 #endif  /* _FUNCTS_H */
