@@ -1,6 +1,8 @@
 #ifndef _GRIDDES_H
 #define _GRIDDES_H
 
+#include <stdbool.h>
+
 typedef struct {
   int    *mask;
   double *xvals;
@@ -12,45 +14,33 @@ typedef struct {
   double  xlast, ylast;
   double  xinc, yinc;
   double  xpole, ypole, angle;    /* rotated north pole             */
-  double  originLon;              /* lambert                        */
-  double  originLat;
-  double  lonParY;
-  double  lat1;
-  double  lat2;
-  int     projflag;
-  int     scanflag;
-  int     def_originLon;
-  int     def_originLat;
-  int     def_lonParY;
-  int     def_lat1;
-  int     def_lat2;
+  int     scanningMode;
+  /* scanningMode  = 128 * iScansNegatively + 64 * jScansPositively + 32 * jPointsAreConsecutive;
+               64  = 128 * 0                + 64 *        1         + 32 * 0  
+               00  = 128 * 0                + 64 *        0         + 32 * 0
+               96  = 128 * 0                + 64 *        1         + 32 * 1
+     Default / implicit scanning mode is 64:
+                        i and j scan positively, i points are consecutive (row-major)        */
+  bool    uvRelativeToGrid;
   double  a;
-  double  lon_0;
-  double  lat_0;
-  double  lat_1;
-  double  lat_2;
-  int     def_lon_0;
-  int     def_lat_0;
-  int     def_lat_1;
-  int     def_lat_2;
   int     prec;
   int     isRotated;              /* TRUE for rotated grids         */
   int     type;
   int     ntr;
   int    *rowlon;
-  int     genBounds;
+  bool    genBounds;
   int     nvertex;
   long    size;
   int     xsize;
   int     ysize;
   int     np;
   int     lcomplex;
-  int     def_xfirst;
-  int     def_yfirst;
-  int     def_xlast;
-  int     def_ylast;
-  int     def_xinc;
-  int     def_yinc;
+  bool    def_xfirst;
+  bool    def_yfirst;
+  bool    def_xlast;
+  bool    def_ylast;
+  bool    def_xinc;
+  bool    def_yinc;
   int     nd, ni, ni2, ni3;
   int     number, position;
   unsigned char uuid[CDI_UUID_SIZE];
@@ -58,9 +48,12 @@ typedef struct {
   char    xname[CDI_MAX_NAME];
   char    xlongname[CDI_MAX_NAME];
   char    xunits[CDI_MAX_NAME];
+  char    xdimname[CDI_MAX_NAME];
   char    yname[CDI_MAX_NAME];
   char    ylongname[CDI_MAX_NAME];
   char    yunits[CDI_MAX_NAME];
+  char    ydimname[CDI_MAX_NAME];
+  char    vdimname[CDI_MAX_NAME];
 }
 griddes_t;
 
