@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2017 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -15,35 +15,37 @@
   GNU General Public License for more details.
 */
 
-#ifndef _PSTREAM_H
-#define _PSTREAM_H
+#ifndef PSTREAM_H
+#define PSTREAM_H
 
 #include "pstream_write.h"
+#include "varlist.h"
 
 #include <sys/types.h> /* off_t */
 
-#define  streamOpenRead           pstreamOpenRead
-#define  streamOpenAppend         pstreamOpenAppend
-#define  streamClose              pstreamClose
-
-#define  streamInqFiletype        pstreamInqFiletype
-#define  streamInqByteorder       pstreamInqByteorder
-
-#define  streamInqVlist           pstreamInqVlist
-
-#define  streamInqTimestep        pstreamInqTimestep
-
-#define  streamInqRecord          pstreamInqRecord
-
-#define  streamReadRecord         pstreamReadRecord
-#define  streamReadRecordF        pstreamReadRecordF
-
-#define  streamCopyRecord         pstreamCopyRecord
-
-#define  streamInqGRIBinfo        pstreamInqGRIBinfo
-
-#define  vlistCopyFlag            cdoVlistCopyFlag
-
+typedef struct {
+  int            self;
+  int            mode;
+  int            fileID;
+  int            vlistID;
+  int            tsID;
+  int            filetype;
+  int            tsID0;
+  int            mfiles;
+  int            nfiles;
+  int            varID;           /* next varID defined with streamDefVar */
+  bool           ispipe;
+  bool           isopen;
+  char          *name;
+  char         **mfnames;
+  varlist_t     *varlist;
+#if defined(HAVE_LIBPTHREAD)
+  void          *argument;
+  struct pipe_s *pipe;
+  pthread_t     rthreadID; /* read  thread ID */
+  pthread_t     wthreadID; /* write thread ID */
+#endif
+} pstream_t;
 
 int     pstreamOpenRead(const argument_t *argument);
 int     pstreamOpenAppend(const argument_t *argument);
@@ -68,4 +70,4 @@ int     pstreamFileID(int pstreamID);
 
 void    cdoVlistCopyFlag(int vlistID2, int vlistID1);
 
-#endif  /* _PSTREAM_H */
+#endif  /* PSTREAM_H */
