@@ -2,7 +2,7 @@
   This file is part of CDO. CDO is a collection of Operators to
   manipulate and analyse Climate model Data.
 
-  Copyright (C) 2003-2016 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
+  Copyright (C) 2003-2017 Uwe Schulzweida, <uwe.schulzweida AT mpimet.mpg.de>
   See COPYING file for copying and redistribution conditions.
 
   This program is free software; you can redistribute it and/or modify
@@ -21,6 +21,6 @@
 #include "pipe.h"
 
 void  pstreamDebug(int debug);
-int   pstreamIsPipe(int streamID);
+pthread_t  pCreateReadThread(argument_t *argument);
 
 #endif  /* _PSTREAM_INT_H */
