@@ -43,6 +43,7 @@
 
 #define  UNCHANGED_RECORD  (processSelf() == 0 && cdoStreamName(0)->argv[0][0] != '-' && cdoRegulargrid == FALSE && cdoDefaultFileType == -1 && cdoDefaultDataType == -1 && cdoDefaultByteorder == -1 )
 
+#include <string>
 extern char *Progname;
 extern char *cdoGridSearchDir;
 extern int CDO_Reduce_Dim;
@@ -50,7 +51,7 @@ extern int CDO_Memtype;
 extern int CDO_Parallel_Read;
 extern int CDO_Append_History;
 extern int CDO_Reset_History;
-extern int timer_read, timer_write; // refactor: both pstream.c and CDIread.c CDIwrite.c defined in cdo.c
+extern int timer_read, timer_write; // refactor: both pstream.cc and CDIread.cc CDIwrite.cc defined in cdo.cc
 
 extern int CDO_optind;
 extern const char *CDO_optarg;
@@ -111,25 +112,14 @@ extern char CDO_File_Suffix[32]; // refactor: added keyword extern
 extern const char *CDO_Version;
 
 
-typedef struct {
-  int    argc;
-  int    argl;
-  char **argv;
-  char  *args;
-} argument_t;
 
-argument_t *file_argument_new(const char *filename);
-void        file_argument_free(argument_t *argument);
-argument_t *argument_new(size_t argc, size_t len);
-void        argument_free(argument_t *argument);
-void        argument_fill(argument_t *argument, int argc, char *argv[]);
 
 char *getProgname(char *string);
-char *getOperator(const char *argument);
+char *GetOperator(const char *argument);
 const char *getOperatorName(const char *xoperator);
+char *getOperatorArg(const char *xoperator);
 const char *cdoComment(void);
 
-argument_t makeArgument(int argc, char *argv[]);
 char *getFileArg(char *argument);
 
 enum {START_DEC, START_JAN};
@@ -177,7 +167,6 @@ int     operatorArgc(void);
 char  **operatorArgv(void);
 void    operatorCheckArgc(int numargs);
 
-const argument_t *cdoStreamName(int cnt);
 
 void    cdoInitialize(void *argument);
 void    cdoFinish(void);
@@ -221,13 +210,14 @@ int zaxisFromName(const char *zaxisname);
 /* refactor: moved here from cdo.h */
 int cdo_omp_get_thread_num(void);
 void cdo_omp_set_num_threads(int nthreads);
+std::string string2lower(std::string str);
 void strtolower(char *str);
 void strtoupper(char *str);
 
-/* refactor: moved here from cdo.c */
-void exp_run(int argc, char *argv[], const char *cdoExpName); // job.c
-void printFeatures(void); // features.c
-void printLibraries(void);  // features.c  
+/* refactor: moved here from cdo.cc */
+void exp_run(int argc, char *argv[], const char *cdoExpName); // job.cc
+void printFeatures(void); // features.cc
+void printLibraries(void);  // features.cc  
 
 int wildcardmatch(const char *w, const char *s);
 
